import type { Completion, CompletionContext, CompletionResult, CompletionSource } from '@codemirror/autocomplete';
import type { CompletionResult as MongoDBCompletionResult } from '../autocompleter';
import type { Token } from './utils';
export declare function mapMongoDBCompletionToCodemirrorCompletion(completion: MongoDBCompletionResult, escape?: 'always' | 'never' | 'invalid'): Completion;
type Prefix = {
    from: number;
    to: number;
    text: string;
};
/**
 * Ace autocompleter "valid" identifier regex
 */
export declare const ID_REGEX: RegExp;
export declare function createCompletionResultForIdPrefix({ prefix, completions, escape, }: {
    prefix: Pick<Prefix, 'from' | 'to'>;
    completions: MongoDBCompletionResult[];
    escape?: 'always' | 'never' | 'invalid';
}): CompletionResult;
type AceCompatCompletionSource = (options: {
    prefix: Prefix;
    token: Token;
    context: CompletionContext;
}) => ReturnType<CompletionSource>;
/**
 * Helper method to create a basic autocompleter for codemirror to match our
 * current ace autocompleter behavior:
 *
 * - Ignore empty prefixes and comments
 * - Autocomplete only when cursor is near something that passes as identifier
 * - Have autocopmletion logic split depending on whether or not autocompletion
 *   happens inside a string token or not
 */
export declare function createAceCompatAutocompleter(completers: {
    String?: AceCompatCompletionSource;
    IdentifierLike?: AceCompatCompletionSource;
}): CompletionSource;
export {};
//# sourceMappingURL=ace-compat-autocompleter.d.ts.map